CreateWorkstationRequest

Struct CreateWorkstationRequest 

#[non_exhaustive]
pub struct CreateWorkstationRequest { pub parent: String, pub workstation_id: String, pub workstation: Option<Workstation>, pub validate_only: bool, /* private fields */ }
Message for creating a CreateWorkstation.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. Parent resource name.

workstation_id: String

Required. ID to use for the workstation.

workstation: Option<Workstation>

Required. Workstation to create. If source_workstation is specified, the user must have workstations.workstations.use permission on the source workstation, and the Cloud Workstations Service Agent for the project where you are creating the new workstation must have compute.disks.createSnapshot and compute.snapshots.useReadOnly on the source project.

validate_only: bool

Optional. If set, validate the request and preview the result, but do not actually apply it.

Implementations

Source

impl CreateWorkstationRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = CreateWorkstationRequest::new().set_parent(format!("projects/{project_id}/locations/{location_id}/workstationClusters/{workstation_cluster_id}/workstationConfigs/{workstation_config_id}"));
pub fn set_workstation_id<T: Into<String>>(self, v: T) -> Self

Sets the value of workstation_id.

Example
let x = CreateWorkstationRequest::new().set_workstation_id("example");
pub fn set_workstation<T>(self, v: T) -> Self
where T: Into<Workstation>,

Sets the value of workstation.

Example
use google_cloud_workstations_v1::model::Workstation;
let x = CreateWorkstationRequest::new().set_workstation(Workstation::default()/* use setters */);
pub fn set_or_clear_workstation<T>(self, v: Option<T>) -> Self
where T: Into<Workstation>,

Sets or clears the value of workstation.

Example
use google_cloud_workstations_v1::model::Workstation;
let x = CreateWorkstationRequest::new().set_or_clear_workstation(Some(Workstation::default()/* use setters */));
let x = CreateWorkstationRequest::new().set_or_clear_workstation(None::<Workstation>);
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self

Sets the value of validate_only.

Example
let x = CreateWorkstationRequest::new().set_validate_only(true);