DeleteWorkstationClusterRequest

Struct DeleteWorkstationClusterRequest 

#[non_exhaustive]
pub struct DeleteWorkstationClusterRequest { pub name: String, pub validate_only: bool, pub etag: String, pub force: bool, /* private fields */ }
Message for deleting a workstation cluster.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Required. Name of the workstation cluster to delete.

validate_only: bool

Optional. If set, validate the request and preview the result, but do not apply it.

etag: String

Optional. If set, the request will be rejected if the latest version of the workstation cluster on the server does not have this ETag.

force: bool

Optional. If set, any workstation configurations and workstations in the workstation cluster are also deleted. Otherwise, the request only works if the workstation cluster has no configurations or workstations.

Implementations

Source

impl DeleteWorkstationClusterRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = DeleteWorkstationClusterRequest::new().set_name(format!("projects/{project_id}/locations/{location_id}/workstationClusters/{workstation_cluster_id}"));
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self

Sets the value of validate_only.

Example
let x = DeleteWorkstationClusterRequest::new().set_validate_only(true);
pub fn set_etag<T: Into<String>>(self, v: T) -> Self

Sets the value of etag.

Example
let x = DeleteWorkstationClusterRequest::new().set_etag("example");
pub fn set_force<T: Into<bool>>(self, v: T) -> Self

Sets the value of force.

Example
let x = DeleteWorkstationClusterRequest::new().set_force(true);