#[non_exhaustive]pub struct DeleteWorkstationRequest {
pub name: String,
pub validate_only: bool,
pub etag: String,
/* private fields */
}Expand description
Request message for DeleteWorkstation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Name of the workstation to delete.
validate_only: boolOptional. If set, validate the request and preview the result, but do not actually apply it.
etag: StringOptional. If set, the request will be rejected if the latest version of the workstation on the server does not have this ETag.
Implementations
Sourceimpl DeleteWorkstationRequest
impl DeleteWorkstationRequest