GenerateAccessTokenRequest

Struct GenerateAccessTokenRequest 

#[non_exhaustive]
pub struct GenerateAccessTokenRequest { pub workstation: String, pub port: i32, pub expiration: Option<Expiration>, /* private fields */ }
Request message for GenerateAccessToken.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
workstation: String

Required. Name of the workstation for which the access token should be generated.

port: i32

Optional. Port for which the access token should be generated. If specified, the generated access token grants access only to the specified port of the workstation. If specified, values must be within the range [1 - 65535]. If not specified, the generated access token grants access to all ports of the workstation.

expiration: Option<Expiration>

Desired expiration or lifetime of the access token.

Implementations

Source

impl GenerateAccessTokenRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_workstation<T: Into<String>>(self, v: T) -> Self

Sets the value of workstation.

Example
let x = GenerateAccessTokenRequest::new().set_workstation(format!("projects/{project_id}/locations/{location_id}/workstationClusters/{workstation_cluster_id}/workstationConfigs/{workstation_config_id}/workstations/{workstation_id}"));
pub fn set_port<T: Into<i32>>(self, v: T) -> Self

Sets the value of port.

Example
let x = GenerateAccessTokenRequest::new().set_port(42);
pub fn set_expiration<T: Into<Option<Expiration>>>(self, v: T) -> Self

Sets the value of expiration.

Note that all the setters affecting expiration are mutually exclusive.

Example
use wkt::Timestamp;
let x = GenerateAccessTokenRequest::new().set_expiration(Some(
    google_cloud_workstations_v1::model::generate_access_token_request::Expiration::ExpireTime(Timestamp::default().into())));
pub fn expire_time(&self) -> Option<&Box<Timestamp>>

The value of expiration if it holds a ExpireTime, None if the field is not set or holds a different branch.

pub fn set_expire_time<T: Into<Box<Timestamp>>>(self, v: T) -> Self

Sets the value of expiration to hold a ExpireTime.

Note that all the setters affecting expiration are mutually exclusive.

Example
use wkt::Timestamp;
let x = GenerateAccessTokenRequest::new().set_expire_time(Timestamp::default()/* use setters */);
assert!(x.expire_time().is_some());
assert!(x.ttl().is_none());
pub fn ttl(&self) -> Option<&Box<Duration>>

The value of expiration if it holds a Ttl, None if the field is not set or holds a different branch.

pub fn set_ttl<T: Into<Box<Duration>>>(self, v: T) -> Self

Sets the value of expiration to hold a Ttl.

Note that all the setters affecting expiration are mutually exclusive.

Example
use wkt::Duration;
let x = GenerateAccessTokenRequest::new().set_ttl(Duration::default()/* use setters */);
assert!(x.ttl().is_some());
assert!(x.expire_time().is_none());