#[non_exhaustive]pub struct ListUsableWorkstationConfigsResponse {
pub workstation_configs: Vec<WorkstationConfig>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response message for ListUsableWorkstationConfigs.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.workstation_configs: Vec<WorkstationConfig>The requested configs.
next_page_token: StringToken to retrieve the next page of results, or empty if there are no more results in the list.
unreachable: Vec<String>Unreachable resources.
Implementations
Sourceimpl ListUsableWorkstationConfigsResponse
impl ListUsableWorkstationConfigsResponse
Sourcepub fn set_workstation_configs<T, V>(self, v: T) -> Self
pub fn set_workstation_configs<T, V>(self, v: T) -> Self
Sets the value of workstation_configs.
Example
ⓘ
use google_cloud_workstations_v1::model::WorkstationConfig;
let x = ListUsableWorkstationConfigsResponse::new()
.set_workstation_configs([
WorkstationConfig::default()/* use setters */,
WorkstationConfig::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListUsableWorkstationConfigsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListUsableWorkstationConfigsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListUsableWorkstationConfigsResponse
impl Clone for ListUsableWorkstationConfigsResponse
Sourcefn clone(&self) -> ListUsableWorkstationConfigsResponse
fn clone(&self) -> ListUsableWorkstationConfigsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListUsableWorkstationConfigsResponse
impl Default for ListUsableWorkstationConfigsResponse
Sourcefn default() -> ListUsableWorkstationConfigsResponse
fn default() -> ListUsableWorkstationConfigsResponse
Returns the “default value” for a type. Read more
impl StructuralPartialEq for ListUsableWorkstationConfigsResponse