#[non_exhaustive]pub struct ListUsableWorkstationsResponse {
pub workstations: Vec<Workstation>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response message for ListUsableWorkstations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.workstations: Vec<Workstation>The requested workstations.
next_page_token: StringToken to retrieve the next page of results, or empty if there are no more results in the list.
unreachable: Vec<String>Unreachable resources.
Implementations
Sourceimpl ListUsableWorkstationsResponse
impl ListUsableWorkstationsResponse
Sourcepub fn set_workstations<T, V>(self, v: T) -> Self
pub fn set_workstations<T, V>(self, v: T) -> Self
Sets the value of workstations.
Example
ⓘ
use google_cloud_workstations_v1::model::Workstation;
let x = ListUsableWorkstationsResponse::new()
.set_workstations([
Workstation::default()/* use setters */,
Workstation::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListUsableWorkstationsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListUsableWorkstationsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListUsableWorkstationsResponse
impl Clone for ListUsableWorkstationsResponse
Sourcefn clone(&self) -> ListUsableWorkstationsResponse
fn clone(&self) -> ListUsableWorkstationsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListUsableWorkstationsResponse
impl Default for ListUsableWorkstationsResponse
Sourcefn default() -> ListUsableWorkstationsResponse
fn default() -> ListUsableWorkstationsResponse
Returns the “default value” for a type. Read more
impl StructuralPartialEq for ListUsableWorkstationsResponse