#[non_exhaustive]pub struct ListWorkstationClustersResponse {
pub workstation_clusters: Vec<WorkstationCluster>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response message for ListWorkstationClusters.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.workstation_clusters: Vec<WorkstationCluster>The requested workstation clusters.
next_page_token: StringToken to retrieve the next page of results, or empty if there are no more results in the list.
unreachable: Vec<String>Unreachable resources.
Implementations
Sourceimpl ListWorkstationClustersResponse
impl ListWorkstationClustersResponse
Sourcepub fn set_workstation_clusters<T, V>(self, v: T) -> Self
pub fn set_workstation_clusters<T, V>(self, v: T) -> Self
Sets the value of workstation_clusters.
Example
ⓘ
use google_cloud_workstations_v1::model::WorkstationCluster;
let x = ListWorkstationClustersResponse::new()
.set_workstation_clusters([
WorkstationCluster::default()/* use setters */,
WorkstationCluster::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListWorkstationClustersResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListWorkstationClustersResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListWorkstationClustersResponse
impl Clone for ListWorkstationClustersResponse
Sourcefn clone(&self) -> ListWorkstationClustersResponse
fn clone(&self) -> ListWorkstationClustersResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListWorkstationClustersResponse
impl Default for ListWorkstationClustersResponse
Sourcefn default() -> ListWorkstationClustersResponse
fn default() -> ListWorkstationClustersResponse
Returns the “default value” for a type. Read more
impl StructuralPartialEq for ListWorkstationClustersResponse