#[non_exhaustive]pub struct ListWorkstationsResponse {
pub workstations: Vec<Workstation>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response message for ListWorkstations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.workstations: Vec<Workstation>The requested workstations.
next_page_token: StringOptional. Token to retrieve the next page of results, or empty if there are no more results in the list.
unreachable: Vec<String>Optional. Unreachable resources.
Implementations
Sourceimpl ListWorkstationsResponse
impl ListWorkstationsResponse
Sourcepub fn set_workstations<T, V>(self, v: T) -> Self
pub fn set_workstations<T, V>(self, v: T) -> Self
Sets the value of workstations.
Example
ⓘ
use google_cloud_workstations_v1::model::Workstation;
let x = ListWorkstationsResponse::new()
.set_workstations([
Workstation::default()/* use setters */,
Workstation::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListWorkstationsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListWorkstationsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListWorkstationsResponse
impl Clone for ListWorkstationsResponse
Sourcefn clone(&self) -> ListWorkstationsResponse
fn clone(&self) -> ListWorkstationsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListWorkstationsResponse
impl Debug for ListWorkstationsResponse
Sourceimpl Default for ListWorkstationsResponse
impl Default for ListWorkstationsResponse
Sourcefn default() -> ListWorkstationsResponse
fn default() -> ListWorkstationsResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ListWorkstationsResponse
impl Message for ListWorkstationsResponse
Sourceimpl PartialEq for ListWorkstationsResponse
impl PartialEq for ListWorkstationsResponse
impl StructuralPartialEq for ListWorkstationsResponse