#[non_exhaustive]pub struct StartWorkstationRequest {
pub name: String,
pub validate_only: bool,
pub etag: String,
pub boost_config: String,
/* private fields */
}Expand description
Request message for StartWorkstation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Name of the workstation to start.
validate_only: boolOptional. If set, validate the request and preview the result, but do not actually apply it.
etag: StringOptional. If set, the request will be rejected if the latest version of the workstation on the server does not have this ETag.
boost_config: StringOptional. If set, the workstation starts using the boost configuration with the specified ID.
Implementations
Sourceimpl StartWorkstationRequest
impl StartWorkstationRequest
Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
ⓘ
let x = StartWorkstationRequest::new().set_validate_only(true);Sourcepub fn set_boost_config<T: Into<String>>(self, v: T) -> Self
pub fn set_boost_config<T: Into<String>>(self, v: T) -> Self
Sets the value of boost_config.
Example
ⓘ
let x = StartWorkstationRequest::new().set_boost_config("example");Trait Implementations
Sourceimpl Clone for StartWorkstationRequest
impl Clone for StartWorkstationRequest
Sourcefn clone(&self) -> StartWorkstationRequest
fn clone(&self) -> StartWorkstationRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StartWorkstationRequest
impl Debug for StartWorkstationRequest
Sourceimpl Default for StartWorkstationRequest
impl Default for StartWorkstationRequest
Sourcefn default() -> StartWorkstationRequest
fn default() -> StartWorkstationRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for StartWorkstationRequest
impl Message for StartWorkstationRequest
Sourceimpl PartialEq for StartWorkstationRequest
impl PartialEq for StartWorkstationRequest
impl StructuralPartialEq for StartWorkstationRequest