#[non_exhaustive]pub struct UpdateWorkstationClusterRequest {
pub workstation_cluster: Option<WorkstationCluster>,
pub update_mask: Option<FieldMask>,
pub validate_only: bool,
pub allow_missing: bool,
/* private fields */
}Expand description
Request message for UpdateWorkstationCluster.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.workstation_cluster: Option<WorkstationCluster>Required. Workstation cluster to update.
update_mask: Option<FieldMask>Required. Mask that specifies which fields in the workstation cluster should be updated.
validate_only: boolOptional. If set, validate the request and preview the result, but do not actually apply it.
allow_missing: boolOptional. If set, and the workstation cluster is not found, a new workstation cluster will be created. In this situation, update_mask is ignored.
Implementations
Sourceimpl UpdateWorkstationClusterRequest
impl UpdateWorkstationClusterRequest
Sourcepub fn set_workstation_cluster<T>(self, v: T) -> Selfwhere
T: Into<WorkstationCluster>,
pub fn set_workstation_cluster<T>(self, v: T) -> Selfwhere
T: Into<WorkstationCluster>,
Sets the value of workstation_cluster.
Example
ⓘ
use google_cloud_workstations_v1::model::WorkstationCluster;
let x = UpdateWorkstationClusterRequest::new().set_workstation_cluster(WorkstationCluster::default()/* use setters */);Sourcepub fn set_or_clear_workstation_cluster<T>(self, v: Option<T>) -> Selfwhere
T: Into<WorkstationCluster>,
pub fn set_or_clear_workstation_cluster<T>(self, v: Option<T>) -> Selfwhere
T: Into<WorkstationCluster>,
Sets or clears the value of workstation_cluster.
Example
ⓘ
use google_cloud_workstations_v1::model::WorkstationCluster;
let x = UpdateWorkstationClusterRequest::new().set_or_clear_workstation_cluster(Some(WorkstationCluster::default()/* use setters */));
let x = UpdateWorkstationClusterRequest::new().set_or_clear_workstation_cluster(None::<WorkstationCluster>);Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateWorkstationClusterRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateWorkstationClusterRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateWorkstationClusterRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
ⓘ
let x = UpdateWorkstationClusterRequest::new().set_validate_only(true);Sourcepub fn set_allow_missing<T: Into<bool>>(self, v: T) -> Self
pub fn set_allow_missing<T: Into<bool>>(self, v: T) -> Self
Sets the value of allow_missing.
Example
ⓘ
let x = UpdateWorkstationClusterRequest::new().set_allow_missing(true);Trait Implementations
Sourceimpl Clone for UpdateWorkstationClusterRequest
impl Clone for UpdateWorkstationClusterRequest
Sourcefn clone(&self) -> UpdateWorkstationClusterRequest
fn clone(&self) -> UpdateWorkstationClusterRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for UpdateWorkstationClusterRequest
impl Default for UpdateWorkstationClusterRequest
Sourcefn default() -> UpdateWorkstationClusterRequest
fn default() -> UpdateWorkstationClusterRequest
Returns the “default value” for a type. Read more
impl StructuralPartialEq for UpdateWorkstationClusterRequest