#[non_exhaustive]pub struct UpdateWorkstationConfigRequest {
pub workstation_config: Option<WorkstationConfig>,
pub update_mask: Option<FieldMask>,
pub validate_only: bool,
pub allow_missing: bool,
/* private fields */
}Expand description
Request message for UpdateWorkstationConfig.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.workstation_config: Option<WorkstationConfig>Required. Config to update.
update_mask: Option<FieldMask>Required. Mask specifying which fields in the workstation configuration should be updated.
validate_only: boolOptional. If set, validate the request and preview the review, but do not actually apply it.
allow_missing: boolOptional. If set and the workstation configuration is not found, a new workstation configuration will be created. In this situation, update_mask is ignored.
Implementations
Sourceimpl UpdateWorkstationConfigRequest
impl UpdateWorkstationConfigRequest
pub fn new() -> Self
Sourcepub fn set_workstation_config<T>(self, v: T) -> Selfwhere
T: Into<WorkstationConfig>,
pub fn set_workstation_config<T>(self, v: T) -> Selfwhere
T: Into<WorkstationConfig>,
Sets the value of workstation_config.
Example
ⓘ
use google_cloud_workstations_v1::model::WorkstationConfig;
let x = UpdateWorkstationConfigRequest::new().set_workstation_config(WorkstationConfig::default()/* use setters */);Sourcepub fn set_or_clear_workstation_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<WorkstationConfig>,
pub fn set_or_clear_workstation_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<WorkstationConfig>,
Sets or clears the value of workstation_config.
Example
ⓘ
use google_cloud_workstations_v1::model::WorkstationConfig;
let x = UpdateWorkstationConfigRequest::new().set_or_clear_workstation_config(Some(WorkstationConfig::default()/* use setters */));
let x = UpdateWorkstationConfigRequest::new().set_or_clear_workstation_config(None::<WorkstationConfig>);Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateWorkstationConfigRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateWorkstationConfigRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateWorkstationConfigRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
ⓘ
let x = UpdateWorkstationConfigRequest::new().set_validate_only(true);Sourcepub fn set_allow_missing<T: Into<bool>>(self, v: T) -> Self
pub fn set_allow_missing<T: Into<bool>>(self, v: T) -> Self
Sets the value of allow_missing.
Example
ⓘ
let x = UpdateWorkstationConfigRequest::new().set_allow_missing(true);Trait Implementations
Sourceimpl Clone for UpdateWorkstationConfigRequest
impl Clone for UpdateWorkstationConfigRequest
Sourcefn clone(&self) -> UpdateWorkstationConfigRequest
fn clone(&self) -> UpdateWorkstationConfigRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for UpdateWorkstationConfigRequest
impl Default for UpdateWorkstationConfigRequest
Sourcefn default() -> UpdateWorkstationConfigRequest
fn default() -> UpdateWorkstationConfigRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for UpdateWorkstationConfigRequest
impl PartialEq for UpdateWorkstationConfigRequest
Sourcefn eq(&self, other: &UpdateWorkstationConfigRequest) -> bool
fn eq(&self, other: &UpdateWorkstationConfigRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateWorkstationConfigRequest