#[non_exhaustive]pub struct UpdateWorkstationRequest {
pub workstation: Option<Workstation>,
pub update_mask: Option<FieldMask>,
pub validate_only: bool,
pub allow_missing: bool,
/* private fields */
}Expand description
Request message for UpdateWorkstation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.workstation: Option<Workstation>Required. Workstation to update.
update_mask: Option<FieldMask>Required. Mask specifying which fields in the workstation should be updated.
validate_only: boolOptional. If set, validate the request and preview the result, but do not actually apply it.
allow_missing: boolOptional. If set and the workstation is not found, a new workstation is created. In this situation, update_mask is ignored.
Implementations
Sourceimpl UpdateWorkstationRequest
impl UpdateWorkstationRequest
Sourcepub fn set_workstation<T>(self, v: T) -> Selfwhere
T: Into<Workstation>,
pub fn set_workstation<T>(self, v: T) -> Selfwhere
T: Into<Workstation>,
Sets the value of workstation.
Example
ⓘ
use google_cloud_workstations_v1::model::Workstation;
let x = UpdateWorkstationRequest::new().set_workstation(Workstation::default()/* use setters */);Sourcepub fn set_or_clear_workstation<T>(self, v: Option<T>) -> Selfwhere
T: Into<Workstation>,
pub fn set_or_clear_workstation<T>(self, v: Option<T>) -> Selfwhere
T: Into<Workstation>,
Sets or clears the value of workstation.
Example
ⓘ
use google_cloud_workstations_v1::model::Workstation;
let x = UpdateWorkstationRequest::new().set_or_clear_workstation(Some(Workstation::default()/* use setters */));
let x = UpdateWorkstationRequest::new().set_or_clear_workstation(None::<Workstation>);Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateWorkstationRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateWorkstationRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateWorkstationRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
ⓘ
let x = UpdateWorkstationRequest::new().set_validate_only(true);Sourcepub fn set_allow_missing<T: Into<bool>>(self, v: T) -> Self
pub fn set_allow_missing<T: Into<bool>>(self, v: T) -> Self
Sets the value of allow_missing.
Example
ⓘ
let x = UpdateWorkstationRequest::new().set_allow_missing(true);Trait Implementations
Sourceimpl Clone for UpdateWorkstationRequest
impl Clone for UpdateWorkstationRequest
Sourcefn clone(&self) -> UpdateWorkstationRequest
fn clone(&self) -> UpdateWorkstationRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateWorkstationRequest
impl Debug for UpdateWorkstationRequest
Sourceimpl Default for UpdateWorkstationRequest
impl Default for UpdateWorkstationRequest
Sourcefn default() -> UpdateWorkstationRequest
fn default() -> UpdateWorkstationRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for UpdateWorkstationRequest
impl Message for UpdateWorkstationRequest
Sourceimpl PartialEq for UpdateWorkstationRequest
impl PartialEq for UpdateWorkstationRequest
impl StructuralPartialEq for UpdateWorkstationRequest