#[non_exhaustive]pub struct WorkstationConfig {Show 26 fields
pub name: String,
pub display_name: String,
pub uid: String,
pub reconciling: bool,
pub annotations: HashMap<String, String>,
pub labels: HashMap<String, String>,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub delete_time: Option<Timestamp>,
pub etag: String,
pub idle_timeout: Option<Duration>,
pub running_timeout: Option<Duration>,
pub max_usable_workstations: i32,
pub host: Option<Host>,
pub persistent_directories: Vec<PersistentDirectory>,
pub ephemeral_directories: Vec<EphemeralDirectory>,
pub container: Option<Container>,
pub encryption_key: Option<CustomerEncryptionKey>,
pub readiness_checks: Vec<ReadinessCheck>,
pub replica_zones: Vec<String>,
pub degraded: bool,
pub conditions: Vec<Status>,
pub enable_audit_agent: bool,
pub disable_tcp_connections: bool,
pub allowed_ports: Vec<PortRange>,
pub grant_workstation_admin_role_on_create: bool,
/* private fields */
}Expand description
A workstation configuration resource in the Cloud Workstations API.
Workstation configurations act as templates for workstations. The workstation configuration defines details such as the workstation virtual machine (VM) instance type, persistent storage, container image defining environment, which IDE or Code Editor to use, and more. Administrators and platform teams can also use Identity and Access Management (IAM) rules to grant access to teams or to individual developers.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. Full name of this workstation configuration.
display_name: StringOptional. Human-readable name for this workstation configuration.
uid: StringOutput only. A system-assigned unique identifier for this workstation configuration.
reconciling: boolOutput only. Indicates whether this workstation configuration is currently being updated to match its intended state.
annotations: HashMap<String, String>Optional. Client-specified annotations.
labels: HashMap<String, String>Optional. Labels that are applied to the workstation configuration and that are also propagated to the underlying Compute Engine resources.
create_time: Option<Timestamp>Output only. Time when this workstation configuration was created.
update_time: Option<Timestamp>Output only. Time when this workstation configuration was most recently updated.
delete_time: Option<Timestamp>Output only. Time when this workstation configuration was soft-deleted.
etag: StringOptional. Checksum computed by the server. May be sent on update and delete requests to make sure that the client has an up-to-date value before proceeding.
idle_timeout: Option<Duration>Optional. Number of seconds to wait before automatically stopping a workstation after it last received user traffic.
A value of "0s" indicates that Cloud Workstations VMs created with this
configuration should never time out due to idleness.
Provide
duration
terminated by s for seconds—for example, "7200s" (2 hours).
The default is "1200s" (20 minutes).
running_timeout: Option<Duration>Optional. Number of seconds that a workstation can run until it is automatically shut down. We recommend that workstations be shut down daily to reduce costs and so that security updates can be applied upon restart. The idle_timeout and running_timeout fields are independent of each other. Note that the running_timeout field shuts down VMs after the specified time, regardless of whether or not the VMs are idle.
Provide duration terminated by s for seconds—for example, "54000s"
(15 hours). Defaults to "43200s" (12 hours). A value of "0s" indicates
that workstations using this configuration should never time out. If
encryption_key
is set, it must be greater than "0s" and less than
"86400s" (24 hours).
Warning: A value of "0s" indicates that Cloud Workstations VMs created
with this configuration have no maximum running time. This is strongly
discouraged because you incur costs and will not pick up security updates.
max_usable_workstations: i32Optional. Maximum number of workstations under this configuration a user
can have workstations.workstation.use permission on.
Only enforced on CreateWorkstation API calls on the user issuing the API request. Can be overridden by:
- granting a user workstations.workstationConfigs.exemptMaxUsableWorkstationLimit permission, or
- having a user with that permission create a workstation and
granting another user
workstations.workstation.usepermission on that workstation.
If not specified, defaults to 0, which indicates unlimited.
host: Option<Host>Optional. Runtime host for the workstation.
persistent_directories: Vec<PersistentDirectory>Optional. Directories to persist across workstation sessions.
ephemeral_directories: Vec<EphemeralDirectory>Optional. Ephemeral directories which won’t persist across workstation sessions.
container: Option<Container>Optional. Container that runs upon startup for each workstation using this workstation configuration.
encryption_key: Option<CustomerEncryptionKey>Immutable. Encrypts resources of this workstation configuration using a customer-managed encryption key (CMEK).
If specified, the boot disk of the Compute Engine instance and the persistent disk are encrypted using this encryption key. If this field is not set, the disks are encrypted using a generated key. Customer-managed encryption keys do not protect disk metadata.
If the customer-managed encryption key is rotated, when the workstation instance is stopped, the system attempts to recreate the persistent disk with the new version of the key. Be sure to keep older versions of the key until the persistent disk is recreated. Otherwise, data on the persistent disk might be lost.
If the encryption key is revoked, the workstation session automatically stops within 7 hours.
Immutable after the workstation configuration is created.
readiness_checks: Vec<ReadinessCheck>Optional. Readiness checks to perform when starting a workstation using this workstation configuration. Mark a workstation as running only after all specified readiness checks return 200 status codes.
replica_zones: Vec<String>Optional. Immutable. Specifies the zones used to replicate the VM and disk
resources within the region. If set, exactly two zones within the
workstation cluster’s region must be specified—for example,
['us-central1-a', 'us-central1-f']. If this field is empty, two default
zones within the region are used.
Immutable after the workstation configuration is created.
degraded: boolOutput only. Whether this workstation configuration is in degraded mode, in which case it may require user action to restore full functionality. The conditions field contains detailed information about the status of the configuration.
conditions: Vec<Status>Output only. Status conditions describing the workstation configuration’s current state.
enable_audit_agent: boolOptional. Whether to enable Linux auditd logging on the workstation. When
enabled, a
service_account
must also be specified that has roles/logging.logWriter and
roles/monitoring.metricWriter on the project. Operating system audit
logging is distinct from Cloud Audit
Logs and
Container output
logging.
Operating system audit logs are available in the
Cloud Logging console by querying:
resource.type="gce_instance"
log_name:"/logs/linux-auditd"disable_tcp_connections: boolOptional. Disables support for plain TCP connections in the workstation. By default the service supports TCP connections through a websocket relay. Setting this option to true disables that relay, which prevents the usage of services that require plain TCP connections, such as SSH. When enabled, all communication must occur over HTTPS or WSS.
allowed_ports: Vec<PortRange>Optional. A list of PortRanges specifying single ports or ranges of ports that are externally accessible in the workstation. Allowed ports must be one of 22, 80, or within range 1024-65535. If not specified defaults to ports 22, 80, and ports 1024-65535.
grant_workstation_admin_role_on_create: boolOptional. Grant creator of a workstation roles/workstations.policyAdmin
role along with roles/workstations.user role on the workstation created
by them. This allows workstation users to share access to either their
entire workstation, or individual ports. Defaults to false.
Implementations
Sourceimpl WorkstationConfig
impl WorkstationConfig
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = WorkstationConfig::new().set_display_name("example");Sourcepub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self
pub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_annotations<T, K, V>(self, v: T) -> Self
pub fn set_annotations<T, K, V>(self, v: T) -> Self
Sets the value of annotations.
Example
let x = WorkstationConfig::new().set_annotations([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = WorkstationConfig::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = WorkstationConfig::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = WorkstationConfig::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = WorkstationConfig::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = WorkstationConfig::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = WorkstationConfig::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_delete_time<T>(self, v: T) -> Self
pub fn set_delete_time<T>(self, v: T) -> Self
Sets the value of delete_time.
Example
use wkt::Timestamp;
let x = WorkstationConfig::new().set_delete_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of delete_time.
Example
use wkt::Timestamp;
let x = WorkstationConfig::new().set_or_clear_delete_time(Some(Timestamp::default()/* use setters */));
let x = WorkstationConfig::new().set_or_clear_delete_time(None::<Timestamp>);Sourcepub fn set_idle_timeout<T>(self, v: T) -> Self
pub fn set_idle_timeout<T>(self, v: T) -> Self
Sets the value of idle_timeout.
Example
use wkt::Duration;
let x = WorkstationConfig::new().set_idle_timeout(Duration::default()/* use setters */);Sourcepub fn set_or_clear_idle_timeout<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_idle_timeout<T>(self, v: Option<T>) -> Self
Sets or clears the value of idle_timeout.
Example
use wkt::Duration;
let x = WorkstationConfig::new().set_or_clear_idle_timeout(Some(Duration::default()/* use setters */));
let x = WorkstationConfig::new().set_or_clear_idle_timeout(None::<Duration>);Sourcepub fn set_running_timeout<T>(self, v: T) -> Self
pub fn set_running_timeout<T>(self, v: T) -> Self
Sets the value of running_timeout.
Example
use wkt::Duration;
let x = WorkstationConfig::new().set_running_timeout(Duration::default()/* use setters */);Sourcepub fn set_or_clear_running_timeout<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_running_timeout<T>(self, v: Option<T>) -> Self
Sets or clears the value of running_timeout.
Example
use wkt::Duration;
let x = WorkstationConfig::new().set_or_clear_running_timeout(Some(Duration::default()/* use setters */));
let x = WorkstationConfig::new().set_or_clear_running_timeout(None::<Duration>);Sourcepub fn set_max_usable_workstations<T: Into<i32>>(self, v: T) -> Self
pub fn set_max_usable_workstations<T: Into<i32>>(self, v: T) -> Self
Sets the value of max_usable_workstations.
Example
let x = WorkstationConfig::new().set_max_usable_workstations(42);Sourcepub fn set_or_clear_host<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_host<T>(self, v: Option<T>) -> Self
Sourcepub fn set_persistent_directories<T, V>(self, v: T) -> Self
pub fn set_persistent_directories<T, V>(self, v: T) -> Self
Sets the value of persistent_directories.
Example
use google_cloud_workstations_v1::model::workstation_config::PersistentDirectory;
let x = WorkstationConfig::new()
.set_persistent_directories([
PersistentDirectory::default()/* use setters */,
PersistentDirectory::default()/* use (different) setters */,
]);Sourcepub fn set_ephemeral_directories<T, V>(self, v: T) -> Self
pub fn set_ephemeral_directories<T, V>(self, v: T) -> Self
Sets the value of ephemeral_directories.
Example
use google_cloud_workstations_v1::model::workstation_config::EphemeralDirectory;
let x = WorkstationConfig::new()
.set_ephemeral_directories([
EphemeralDirectory::default()/* use setters */,
EphemeralDirectory::default()/* use (different) setters */,
]);Sourcepub fn set_container<T>(self, v: T) -> Self
pub fn set_container<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_container<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_container<T>(self, v: Option<T>) -> Self
Sourcepub fn set_encryption_key<T>(self, v: T) -> Selfwhere
T: Into<CustomerEncryptionKey>,
pub fn set_encryption_key<T>(self, v: T) -> Selfwhere
T: Into<CustomerEncryptionKey>,
Sets the value of encryption_key.
Example
use google_cloud_workstations_v1::model::workstation_config::CustomerEncryptionKey;
let x = WorkstationConfig::new().set_encryption_key(CustomerEncryptionKey::default()/* use setters */);Sourcepub fn set_or_clear_encryption_key<T>(self, v: Option<T>) -> Selfwhere
T: Into<CustomerEncryptionKey>,
pub fn set_or_clear_encryption_key<T>(self, v: Option<T>) -> Selfwhere
T: Into<CustomerEncryptionKey>,
Sets or clears the value of encryption_key.
Example
use google_cloud_workstations_v1::model::workstation_config::CustomerEncryptionKey;
let x = WorkstationConfig::new().set_or_clear_encryption_key(Some(CustomerEncryptionKey::default()/* use setters */));
let x = WorkstationConfig::new().set_or_clear_encryption_key(None::<CustomerEncryptionKey>);Sourcepub fn set_readiness_checks<T, V>(self, v: T) -> Self
pub fn set_readiness_checks<T, V>(self, v: T) -> Self
Sets the value of readiness_checks.
Example
use google_cloud_workstations_v1::model::workstation_config::ReadinessCheck;
let x = WorkstationConfig::new()
.set_readiness_checks([
ReadinessCheck::default()/* use setters */,
ReadinessCheck::default()/* use (different) setters */,
]);Sourcepub fn set_replica_zones<T, V>(self, v: T) -> Self
pub fn set_replica_zones<T, V>(self, v: T) -> Self
Sets the value of replica_zones.
Example
let x = WorkstationConfig::new().set_replica_zones(["a", "b", "c"]);Sourcepub fn set_degraded<T: Into<bool>>(self, v: T) -> Self
pub fn set_degraded<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_conditions<T, V>(self, v: T) -> Self
pub fn set_conditions<T, V>(self, v: T) -> Self
Sets the value of conditions.
Example
use google_cloud_rpc::model::Status;
let x = WorkstationConfig::new()
.set_conditions([
Status::default()/* use setters */,
Status::default()/* use (different) setters */,
]);Sourcepub fn set_enable_audit_agent<T: Into<bool>>(self, v: T) -> Self
pub fn set_enable_audit_agent<T: Into<bool>>(self, v: T) -> Self
Sets the value of enable_audit_agent.
Example
let x = WorkstationConfig::new().set_enable_audit_agent(true);Sourcepub fn set_disable_tcp_connections<T: Into<bool>>(self, v: T) -> Self
pub fn set_disable_tcp_connections<T: Into<bool>>(self, v: T) -> Self
Sets the value of disable_tcp_connections.
Example
let x = WorkstationConfig::new().set_disable_tcp_connections(true);Sourcepub fn set_allowed_ports<T, V>(self, v: T) -> Self
pub fn set_allowed_ports<T, V>(self, v: T) -> Self
Sets the value of allowed_ports.
Example
use google_cloud_workstations_v1::model::workstation_config::PortRange;
let x = WorkstationConfig::new()
.set_allowed_ports([
PortRange::default()/* use setters */,
PortRange::default()/* use (different) setters */,
]);Sourcepub fn set_grant_workstation_admin_role_on_create<T: Into<bool>>(
self,
v: T,
) -> Self
pub fn set_grant_workstation_admin_role_on_create<T: Into<bool>>( self, v: T, ) -> Self
Sets the value of grant_workstation_admin_role_on_create.
Example
let x = WorkstationConfig::new().set_grant_workstation_admin_role_on_create(true);Trait Implementations
Sourceimpl Clone for WorkstationConfig
impl Clone for WorkstationConfig
Sourcefn clone(&self) -> WorkstationConfig
fn clone(&self) -> WorkstationConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for WorkstationConfig
impl Debug for WorkstationConfig
Sourceimpl Default for WorkstationConfig
impl Default for WorkstationConfig
Sourcefn default() -> WorkstationConfig
fn default() -> WorkstationConfig
Sourceimpl Message for WorkstationConfig
impl Message for WorkstationConfig
Sourceimpl PartialEq for WorkstationConfig
impl PartialEq for WorkstationConfig
Sourcefn eq(&self, other: &WorkstationConfig) -> bool
fn eq(&self, other: &WorkstationConfig) -> bool
self and other values to be equal, and is used by ==.