#[non_exhaustive]pub enum State {
Unspecified,
Starting,
Running,
Stopping,
Stopped,
UnknownValue(UnknownValue),
}Expand description
Whether a workstation is running and ready to receive user requests.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Do not use.
Starting
The workstation is not yet ready to accept requests from users but will be soon.
Running
The workstation is ready to accept requests from users.
Stopping
The workstation is being stopped.
Stopped
The workstation is stopped and will not be able to receive requests until it is started.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.
Implementations