#[non_exhaustive]pub struct WorkstationPersistentDirectory {
pub mount_path: String,
pub size_gb: i32,
/* private fields */
}Expand description
A directory to persist across workstation sessions. Updates to this field will only take effect on this workstation after it is restarted.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.mount_path: StringOptional. The mount path of the persistent directory.
size_gb: i32Optional. Size of the persistent directory in GB. If specified in an update request, this is the desired size of the directory.
Implementations
Sourceimpl WorkstationPersistentDirectory
impl WorkstationPersistentDirectory
Sourcepub fn set_mount_path<T: Into<String>>(self, v: T) -> Self
pub fn set_mount_path<T: Into<String>>(self, v: T) -> Self
Sets the value of mount_path.
Example
ⓘ
let x = WorkstationPersistentDirectory::new().set_mount_path("example");Trait Implementations
Sourceimpl Clone for WorkstationPersistentDirectory
impl Clone for WorkstationPersistentDirectory
Sourcefn clone(&self) -> WorkstationPersistentDirectory
fn clone(&self) -> WorkstationPersistentDirectory
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for WorkstationPersistentDirectory
impl Default for WorkstationPersistentDirectory
Sourcefn default() -> WorkstationPersistentDirectory
fn default() -> WorkstationPersistentDirectory
Returns the “default value” for a type. Read more
impl StructuralPartialEq for WorkstationPersistentDirectory