#[non_exhaustive]pub struct PersistentDirectory {
pub mount_path: String,
pub directory_type: Option<DirectoryType>,
/* private fields */
}Expand description
A directory to persist across workstation sessions. Updates to this field will not update existing workstations and will only take effect on new workstations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.mount_path: StringOptional. Location of this directory in the running workstation.
directory_type: Option<DirectoryType>How a persistent directory should be implemented.
Implementations
Sourceimpl PersistentDirectory
impl PersistentDirectory
Sourcepub fn set_mount_path<T: Into<String>>(self, v: T) -> Self
pub fn set_mount_path<T: Into<String>>(self, v: T) -> Self
Sets the value of mount_path.
Example
let x = PersistentDirectory::new().set_mount_path("example");Sourcepub fn set_directory_type<T: Into<Option<DirectoryType>>>(self, v: T) -> Self
pub fn set_directory_type<T: Into<Option<DirectoryType>>>(self, v: T) -> Self
Sets the value of directory_type.
Note that all the setters affecting directory_type are mutually
exclusive.
Example
use google_cloud_workstations_v1::model::workstation_config::persistent_directory::GceRegionalPersistentDisk;
let x = PersistentDirectory::new().set_directory_type(Some(
google_cloud_workstations_v1::model::workstation_config::persistent_directory::DirectoryType::GcePd(GceRegionalPersistentDisk::default().into())));Sourcepub fn gce_pd(&self) -> Option<&Box<GceRegionalPersistentDisk>>
pub fn gce_pd(&self) -> Option<&Box<GceRegionalPersistentDisk>>
The value of directory_type
if it holds a GcePd, None if the field is not set or
holds a different branch.
Sourcepub fn set_gce_pd<T: Into<Box<GceRegionalPersistentDisk>>>(self, v: T) -> Self
pub fn set_gce_pd<T: Into<Box<GceRegionalPersistentDisk>>>(self, v: T) -> Self
Sets the value of directory_type
to hold a GcePd.
Note that all the setters affecting directory_type are
mutually exclusive.
Example
use google_cloud_workstations_v1::model::workstation_config::persistent_directory::GceRegionalPersistentDisk;
let x = PersistentDirectory::new().set_gce_pd(GceRegionalPersistentDisk::default()/* use setters */);
assert!(x.gce_pd().is_some());
assert!(x.gce_hd().is_none());Sourcepub fn gce_hd(&self) -> Option<&Box<GceHyperdiskBalancedHighAvailability>>
pub fn gce_hd(&self) -> Option<&Box<GceHyperdiskBalancedHighAvailability>>
The value of directory_type
if it holds a GceHd, None if the field is not set or
holds a different branch.
Sourcepub fn set_gce_hd<T: Into<Box<GceHyperdiskBalancedHighAvailability>>>(
self,
v: T,
) -> Self
pub fn set_gce_hd<T: Into<Box<GceHyperdiskBalancedHighAvailability>>>( self, v: T, ) -> Self
Sets the value of directory_type
to hold a GceHd.
Note that all the setters affecting directory_type are
mutually exclusive.
Example
use google_cloud_workstations_v1::model::workstation_config::persistent_directory::GceHyperdiskBalancedHighAvailability;
let x = PersistentDirectory::new().set_gce_hd(GceHyperdiskBalancedHighAvailability::default()/* use setters */);
assert!(x.gce_hd().is_some());
assert!(x.gce_pd().is_none());Trait Implementations
Sourceimpl Clone for PersistentDirectory
impl Clone for PersistentDirectory
Sourcefn clone(&self) -> PersistentDirectory
fn clone(&self) -> PersistentDirectory
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PersistentDirectory
impl Debug for PersistentDirectory
Sourceimpl Default for PersistentDirectory
impl Default for PersistentDirectory
Sourcefn default() -> PersistentDirectory
fn default() -> PersistentDirectory
Sourceimpl Message for PersistentDirectory
impl Message for PersistentDirectory
Sourceimpl PartialEq for PersistentDirectory
impl PartialEq for PersistentDirectory
impl StructuralPartialEq for PersistentDirectory