#[non_exhaustive]pub struct DeleteWorkstationClusterRequest {
pub name: String,
pub validate_only: bool,
pub etag: String,
pub force: bool,
/* private fields */
}Expand description
Message for deleting a workstation cluster.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Name of the workstation cluster to delete.
validate_only: boolOptional. If set, validate the request and preview the result, but do not apply it.
etag: StringOptional. If set, the request will be rejected if the latest version of the workstation cluster on the server does not have this ETag.
force: boolOptional. If set, any workstation configurations and workstations in the workstation cluster are also deleted. Otherwise, the request only works if the workstation cluster has no configurations or workstations.
Implementations
Sourceimpl DeleteWorkstationClusterRequest
impl DeleteWorkstationClusterRequest