#[non_exhaustive]pub struct DeleteWorkstationConfigRequest {
pub name: String,
pub validate_only: bool,
pub etag: String,
pub force: bool,
/* private fields */
}Expand description
Message for deleting a workstation configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Name of the workstation configuration to delete.
validate_only: boolOptional. If set, validate the request and preview the result, but do not actually apply it.
etag: StringOptional. If set, the request is rejected if the latest version of the workstation configuration on the server does not have this ETag.
force: boolOptional. If set, any workstations in the workstation configuration are also deleted. Otherwise, the request works only if the workstation configuration has no workstations.
Implementations
Sourceimpl DeleteWorkstationConfigRequest
impl DeleteWorkstationConfigRequest