#[non_exhaustive]pub struct Workstation {Show 18 fields
pub name: String,
pub display_name: String,
pub uid: String,
pub reconciling: bool,
pub annotations: HashMap<String, String>,
pub labels: HashMap<String, String>,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub start_time: Option<Timestamp>,
pub delete_time: Option<Timestamp>,
pub etag: String,
pub persistent_directories: Vec<WorkstationPersistentDirectory>,
pub state: State,
pub host: String,
pub env: HashMap<String, String>,
pub kms_key: String,
pub source_workstation: String,
pub runtime_host: Option<RuntimeHost>,
/* private fields */
}Expand description
A single instance of a developer workstation with its own persistent storage.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. Full name of this workstation.
display_name: StringOptional. Human-readable name for this workstation.
uid: StringOutput only. A system-assigned unique identifier for this workstation.
reconciling: boolOutput only. Indicates whether this workstation is currently being updated to match its intended state.
annotations: HashMap<String, String>Optional. Client-specified annotations.
labels: HashMap<String, String>Optional. Labels that are applied to the workstation and that are also propagated to the underlying Compute Engine resources.
create_time: Option<Timestamp>Output only. Time when this workstation was created.
update_time: Option<Timestamp>Output only. Time when this workstation was most recently updated.
start_time: Option<Timestamp>Output only. Time when this workstation was most recently successfully started, regardless of the workstation’s initial state.
delete_time: Option<Timestamp>Output only. Time when this workstation was soft-deleted.
etag: StringOptional. Checksum computed by the server. May be sent on update and delete requests to make sure that the client has an up-to-date value before proceeding.
persistent_directories: Vec<WorkstationPersistentDirectory>Optional. Directories to persist across workstation sessions.
state: StateOutput only. Current state of the workstation.
host: StringOutput only. Host to which clients can send HTTPS traffic that will be
received by the workstation. Authorized traffic will be received to the
workstation as HTTP on port 80. To send traffic to a different port,
clients may prefix the host with the destination port in the format
{port}-{host}.
env: HashMap<String, String>Optional. Environment variables passed to the workstation container’s entrypoint.
kms_key: StringOutput only. The name of the Google Cloud KMS encryption key used to
encrypt this workstation. The KMS key can only be configured in the
WorkstationConfig. The expected format is
projects/*/locations/*/keyRings/*/cryptoKeys/*.
source_workstation: StringOptional. The source workstation from which this workstation’s persistent directories were cloned on creation.
runtime_host: Option<RuntimeHost>Optional. Output only. Runtime host for the workstation when in STATE_RUNNING.
Implementations
Sourceimpl Workstation
impl Workstation
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self
pub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_annotations<T, K, V>(self, v: T) -> Self
pub fn set_annotations<T, K, V>(self, v: T) -> Self
Sets the value of annotations.
Example
let x = Workstation::new().set_annotations([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Workstation::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Workstation::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Workstation::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Workstation::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Workstation::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Workstation::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Example
use wkt::Timestamp;
let x = Workstation::new().set_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Example
use wkt::Timestamp;
let x = Workstation::new().set_or_clear_start_time(Some(Timestamp::default()/* use setters */));
let x = Workstation::new().set_or_clear_start_time(None::<Timestamp>);Sourcepub fn set_delete_time<T>(self, v: T) -> Self
pub fn set_delete_time<T>(self, v: T) -> Self
Sets the value of delete_time.
Example
use wkt::Timestamp;
let x = Workstation::new().set_delete_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of delete_time.
Example
use wkt::Timestamp;
let x = Workstation::new().set_or_clear_delete_time(Some(Timestamp::default()/* use setters */));
let x = Workstation::new().set_or_clear_delete_time(None::<Timestamp>);Sourcepub fn set_persistent_directories<T, V>(self, v: T) -> Self
pub fn set_persistent_directories<T, V>(self, v: T) -> Self
Sets the value of persistent_directories.
Example
use google_cloud_workstations_v1::model::workstation::WorkstationPersistentDirectory;
let x = Workstation::new()
.set_persistent_directories([
WorkstationPersistentDirectory::default()/* use setters */,
WorkstationPersistentDirectory::default()/* use (different) setters */,
]);Sourcepub fn set_kms_key<T: Into<String>>(self, v: T) -> Self
pub fn set_kms_key<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_source_workstation<T: Into<String>>(self, v: T) -> Self
pub fn set_source_workstation<T: Into<String>>(self, v: T) -> Self
Sets the value of source_workstation.
Example
let x = Workstation::new().set_source_workstation("example");Sourcepub fn set_runtime_host<T>(self, v: T) -> Selfwhere
T: Into<RuntimeHost>,
pub fn set_runtime_host<T>(self, v: T) -> Selfwhere
T: Into<RuntimeHost>,
Sets the value of runtime_host.
Example
use google_cloud_workstations_v1::model::workstation::RuntimeHost;
let x = Workstation::new().set_runtime_host(RuntimeHost::default()/* use setters */);Sourcepub fn set_or_clear_runtime_host<T>(self, v: Option<T>) -> Selfwhere
T: Into<RuntimeHost>,
pub fn set_or_clear_runtime_host<T>(self, v: Option<T>) -> Selfwhere
T: Into<RuntimeHost>,
Sets or clears the value of runtime_host.
Example
use google_cloud_workstations_v1::model::workstation::RuntimeHost;
let x = Workstation::new().set_or_clear_runtime_host(Some(RuntimeHost::default()/* use setters */));
let x = Workstation::new().set_or_clear_runtime_host(None::<RuntimeHost>);Trait Implementations
Sourceimpl Clone for Workstation
impl Clone for Workstation
Sourcefn clone(&self) -> Workstation
fn clone(&self) -> Workstation
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for Workstation
impl Debug for Workstation
Sourceimpl Default for Workstation
impl Default for Workstation
Sourcefn default() -> Workstation
fn default() -> Workstation
Sourceimpl Message for Workstation
impl Message for Workstation
Sourceimpl PartialEq for Workstation
impl PartialEq for Workstation
impl StructuralPartialEq for Workstation