Workstation

Struct Workstation 

#[non_exhaustive]
pub struct Workstation {
Show 13 fields pub name: String, pub display_name: String, pub uid: String, pub reconciling: bool, pub annotations: HashMap<String, String>, pub labels: HashMap<String, String>, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub start_time: Option<Timestamp>, pub delete_time: Option<Timestamp>, pub etag: String, pub state: State, pub host: String, /* private fields */
}
A single instance of a developer workstation with its own persistent storage.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Full name of this workstation.

display_name: String

Optional. Human-readable name for this workstation.

uid: String

Output only. A system-assigned unique identifier for this workstation.

reconciling: bool

Output only. Indicates whether this workstation is currently being updated to match its intended state.

annotations: HashMap<String, String>

Optional. Client-specified annotations.

labels: HashMap<String, String>

Optional. Labels that are applied to the workstation and that are also propagated to the underlying Compute Engine resources.

create_time: Option<Timestamp>

Output only. Time when this workstation was created.

update_time: Option<Timestamp>

Output only. Time when this workstation was most recently updated.

start_time: Option<Timestamp>

Output only. Time when this workstation was most recently successfully started, regardless of the workstation’s initial state.

delete_time: Option<Timestamp>

Output only. Time when this workstation was soft-deleted.

etag: String

Optional. Checksum computed by the server. May be sent on update and delete requests to make sure that the client has an up-to-date value before proceeding.

state: State

Output only. Current state of the workstation.

host: String

Output only. Host to which clients can send HTTPS traffic that will be received by the workstation. Authorized traffic will be received to the workstation as HTTP on port 80. To send traffic to a different port, clients may prefix the host with the destination port in the format {port}-{host}.

Implementations

Source

impl Workstation

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = Workstation::new().set_name("example");
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self

Sets the value of display_name.

Example
let x = Workstation::new().set_display_name("example");
pub fn set_uid<T: Into<String>>(self, v: T) -> Self

Sets the value of uid.

Example
let x = Workstation::new().set_uid("example");
pub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self

Sets the value of reconciling.

Example
let x = Workstation::new().set_reconciling(true);
pub fn set_annotations<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of annotations.

Example
let x = Workstation::new().set_annotations([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = Workstation::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = Workstation::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = Workstation::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Workstation::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = Workstation::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = Workstation::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Workstation::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_start_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of start_time.

Example
use wkt::Timestamp;
let x = Workstation::new().set_start_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of start_time.

Example
use wkt::Timestamp;
let x = Workstation::new().set_or_clear_start_time(Some(Timestamp::default()/* use setters */));
let x = Workstation::new().set_or_clear_start_time(None::<Timestamp>);
pub fn set_delete_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of delete_time.

Example
use wkt::Timestamp;
let x = Workstation::new().set_delete_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of delete_time.

Example
use wkt::Timestamp;
let x = Workstation::new().set_or_clear_delete_time(Some(Timestamp::default()/* use setters */));
let x = Workstation::new().set_or_clear_delete_time(None::<Timestamp>);
pub fn set_etag<T: Into<String>>(self, v: T) -> Self

Sets the value of etag.

Example
let x = Workstation::new().set_etag("example");
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_workstations_v1::model::workstation::State;
let x0 = Workstation::new().set_state(State::Starting);
let x1 = Workstation::new().set_state(State::Running);
let x2 = Workstation::new().set_state(State::Stopping);
pub fn set_host<T: Into<String>>(self, v: T) -> Self

Sets the value of host.

Example
let x = Workstation::new().set_host("example");