#[non_exhaustive]pub struct Workstation {Show 13 fields
pub name: String,
pub display_name: String,
pub uid: String,
pub reconciling: bool,
pub annotations: HashMap<String, String>,
pub labels: HashMap<String, String>,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub start_time: Option<Timestamp>,
pub delete_time: Option<Timestamp>,
pub etag: String,
pub state: State,
pub host: String,
/* private fields */
}Expand description
A single instance of a developer workstation with its own persistent storage.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringFull name of this workstation.
display_name: StringOptional. Human-readable name for this workstation.
uid: StringOutput only. A system-assigned unique identifier for this workstation.
reconciling: boolOutput only. Indicates whether this workstation is currently being updated to match its intended state.
annotations: HashMap<String, String>Optional. Client-specified annotations.
labels: HashMap<String, String>Optional. Labels that are applied to the workstation and that are also propagated to the underlying Compute Engine resources.
create_time: Option<Timestamp>Output only. Time when this workstation was created.
update_time: Option<Timestamp>Output only. Time when this workstation was most recently updated.
start_time: Option<Timestamp>Output only. Time when this workstation was most recently successfully started, regardless of the workstation’s initial state.
delete_time: Option<Timestamp>Output only. Time when this workstation was soft-deleted.
etag: StringOptional. Checksum computed by the server. May be sent on update and delete requests to make sure that the client has an up-to-date value before proceeding.
state: StateOutput only. Current state of the workstation.
host: StringOutput only. Host to which clients can send HTTPS traffic that will be
received by the workstation. Authorized traffic will be received to the
workstation as HTTP on port 80. To send traffic to a different port,
clients may prefix the host with the destination port in the format
{port}-{host}.
Implementations
Sourceimpl Workstation
impl Workstation
pub fn new() -> Self
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self
pub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_annotations<T, K, V>(self, v: T) -> Self
pub fn set_annotations<T, K, V>(self, v: T) -> Self
Sets the value of annotations.
Example
let x = Workstation::new().set_annotations([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Workstation::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Workstation::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Workstation::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Workstation::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Workstation::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Workstation::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Example
use wkt::Timestamp;
let x = Workstation::new().set_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Example
use wkt::Timestamp;
let x = Workstation::new().set_or_clear_start_time(Some(Timestamp::default()/* use setters */));
let x = Workstation::new().set_or_clear_start_time(None::<Timestamp>);Sourcepub fn set_delete_time<T>(self, v: T) -> Self
pub fn set_delete_time<T>(self, v: T) -> Self
Sets the value of delete_time.
Example
use wkt::Timestamp;
let x = Workstation::new().set_delete_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of delete_time.
Example
use wkt::Timestamp;
let x = Workstation::new().set_or_clear_delete_time(Some(Timestamp::default()/* use setters */));
let x = Workstation::new().set_or_clear_delete_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for Workstation
impl Clone for Workstation
Sourcefn clone(&self) -> Workstation
fn clone(&self) -> Workstation
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more