#[non_exhaustive]pub struct WorkstationCluster {Show 16 fields
pub name: String,
pub display_name: String,
pub uid: String,
pub reconciling: bool,
pub annotations: HashMap<String, String>,
pub labels: HashMap<String, String>,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub delete_time: Option<Timestamp>,
pub etag: String,
pub network: String,
pub subnetwork: String,
pub control_plane_ip: String,
pub private_cluster_config: Option<PrivateClusterConfig>,
pub degraded: bool,
pub conditions: Vec<Status>,
/* private fields */
}Expand description
A workstation cluster resource in the Cloud Workstations API.
Defines a group of workstations in a particular region and the VPC network they’re attached to.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringFull name of this workstation cluster.
display_name: StringOptional. Human-readable name for this workstation cluster.
uid: StringOutput only. A system-assigned unique identifier for this workstation cluster.
reconciling: boolOutput only. Indicates whether this workstation cluster is currently being updated to match its intended state.
annotations: HashMap<String, String>Optional. Client-specified annotations.
labels: HashMap<String, String>Optional. Labels that are applied to the workstation cluster and that are also propagated to the underlying Compute Engine resources.
create_time: Option<Timestamp>Output only. Time when this workstation cluster was created.
update_time: Option<Timestamp>Output only. Time when this workstation cluster was most recently updated.
delete_time: Option<Timestamp>Output only. Time when this workstation cluster was soft-deleted.
etag: StringOptional. Checksum computed by the server. May be sent on update and delete requests to make sure that the client has an up-to-date value before proceeding.
network: StringImmutable. Name of the Compute Engine network in which instances associated with this workstation cluster will be created.
subnetwork: StringImmutable. Name of the Compute Engine subnetwork in which instances associated with this workstation cluster will be created. Must be part of the subnetwork specified for this workstation cluster.
control_plane_ip: StringOutput only. The private IP address of the control plane for this workstation cluster. Workstation VMs need access to this IP address to work with the service, so make sure that your firewall rules allow egress from the workstation VMs to this address.
private_cluster_config: Option<PrivateClusterConfig>Optional. Configuration for private workstation cluster.
degraded: boolOutput only. Whether this workstation cluster is in degraded mode, in which case it may require user action to restore full functionality. Details can be found in conditions.
conditions: Vec<Status>Output only. Status conditions describing the workstation cluster’s current state.
Implementations
Sourceimpl WorkstationCluster
impl WorkstationCluster
pub fn new() -> Self
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = WorkstationCluster::new().set_display_name("example");Sourcepub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self
pub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_annotations<T, K, V>(self, v: T) -> Self
pub fn set_annotations<T, K, V>(self, v: T) -> Self
Sets the value of annotations.
Example
let x = WorkstationCluster::new().set_annotations([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = WorkstationCluster::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = WorkstationCluster::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = WorkstationCluster::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = WorkstationCluster::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = WorkstationCluster::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = WorkstationCluster::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_delete_time<T>(self, v: T) -> Self
pub fn set_delete_time<T>(self, v: T) -> Self
Sets the value of delete_time.
Example
use wkt::Timestamp;
let x = WorkstationCluster::new().set_delete_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of delete_time.
Example
use wkt::Timestamp;
let x = WorkstationCluster::new().set_or_clear_delete_time(Some(Timestamp::default()/* use setters */));
let x = WorkstationCluster::new().set_or_clear_delete_time(None::<Timestamp>);Sourcepub fn set_network<T: Into<String>>(self, v: T) -> Self
pub fn set_network<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_subnetwork<T: Into<String>>(self, v: T) -> Self
pub fn set_subnetwork<T: Into<String>>(self, v: T) -> Self
Sets the value of subnetwork.
Example
let x = WorkstationCluster::new().set_subnetwork("example");Sourcepub fn set_control_plane_ip<T: Into<String>>(self, v: T) -> Self
pub fn set_control_plane_ip<T: Into<String>>(self, v: T) -> Self
Sets the value of control_plane_ip.
Example
let x = WorkstationCluster::new().set_control_plane_ip("example");Sourcepub fn set_private_cluster_config<T>(self, v: T) -> Selfwhere
T: Into<PrivateClusterConfig>,
pub fn set_private_cluster_config<T>(self, v: T) -> Selfwhere
T: Into<PrivateClusterConfig>,
Sets the value of private_cluster_config.
Example
use google_cloud_workstations_v1::model::workstation_cluster::PrivateClusterConfig;
let x = WorkstationCluster::new().set_private_cluster_config(PrivateClusterConfig::default()/* use setters */);Sourcepub fn set_or_clear_private_cluster_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<PrivateClusterConfig>,
pub fn set_or_clear_private_cluster_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<PrivateClusterConfig>,
Sets or clears the value of private_cluster_config.
Example
use google_cloud_workstations_v1::model::workstation_cluster::PrivateClusterConfig;
let x = WorkstationCluster::new().set_or_clear_private_cluster_config(Some(PrivateClusterConfig::default()/* use setters */));
let x = WorkstationCluster::new().set_or_clear_private_cluster_config(None::<PrivateClusterConfig>);Sourcepub fn set_degraded<T: Into<bool>>(self, v: T) -> Self
pub fn set_degraded<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_conditions<T, V>(self, v: T) -> Self
pub fn set_conditions<T, V>(self, v: T) -> Self
Sets the value of conditions.
Example
use google_cloud_rpc::model::Status;
let x = WorkstationCluster::new()
.set_conditions([
Status::default()/* use setters */,
Status::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for WorkstationCluster
impl Clone for WorkstationCluster
Sourcefn clone(&self) -> WorkstationCluster
fn clone(&self) -> WorkstationCluster
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more